```
🕙 分享是一种美德，右上随手点个 🌟 Star，谢谢
```
 
**温馨提醒**
 
1. 本项目仅适用学习交流
2. 本项目不在任何平台出售,如有发现请积极举报<br/>
3. 为了更好的体验，友情提示此项目是一个全栈项目，认真刻苦的掌握它，熟练掌握后你就比较牛掰了<br/>
4. 不要只是白嫖 ,如果帮到你了麻烦**点个Star**<br/>
5. 发现有问题？添加下方微信客服一起探讨，或者直接提Issues
 
  
 
## 项目简介
 
ts-soup 项目是一款时序数据同步软件，提供自动记录各类型数据同步时间等多种功能，为用户提供便捷高效的体验
 
 